# About the package

**pst_wrinkle** is a Python package designed to showcase selected functions from the Pf7-Public-Notebooks project within a concise public notebook. Please note that this project is currently a work in progress and may be temporary.

## Installation

You can install `pst_wrinkle` using pip:

```bash
!pip install pst-wrinkle
```

## Usage

To import the the package:

```bash
import pst_wrinkle.pst_wrinkle as pst_wrinkle
```

Example of running a function: 

```bash
pst_wrinkle.sample_viewer('PD0129-C', 8, 29000, 30300)
```

